Index: trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h
===================================================================
--- trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h	(revision 1068)
+++ trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h	(revision 1069)
@@ -19,7 +19,7 @@
 //=
 //= $RCSfile: creadparam.h,v $
-//= $Revision: 1.9 $
+//= $Revision: 1.10 $
 //= $Author: blanch $ 
-//= $Date: 2001-07-19 09:29:02 $
+//= $Date: 2001-11-13 17:06:01 $
 //=
 //=//////////////////////////////////////////////////////////////////////
@@ -135,12 +135,13 @@
 //!@{
 
 // now we define the list ITEM_LIST of possible items in
 // the parameters file. note that they are functions of
 // T(x). we will change T(x) to be the real item or the
 // string of this item when needed
 
-#define ITEM_LIST   /* LIST OF ITEMS IN THE PARAMETERS FILE */     \
+#define PM_ITEM_LIST   /* LIST OF ITEMS IN THE PARAMETERS FILE */     \
 T(input_file),      /* input file */                              \
 T(starfield_file),  /* starfield file */                              \
+T(starfield_center),/* center of thestarfield FOV */                    \
 T(data_file),       /* data file */                              \
 T(root_file),       /* ROOT file */                              \
@@ -176,4 +177,7 @@
 T(trigger_single),  /* trigger conditions */ \
 T(Trigger_Loop_Output_Only_Specialists),   /* special steercard */ \
+T(telescope_axis),   /* Direction of the axis telescope */ \
+T(source_offset),   /* Displacement of the source from the center */ \
+T(corsika_vers),    /* Version of Corsika */ \
 T(end_file)         /* end of the parameters file */
   
@@ -181,5 +185,5 @@
 
 enum ITEM_TYPE {
-  ITEM_LIST
+  PM_ITEM_LIST
 };
 
@@ -189,5 +193,5 @@
 
 const char *const ITEM_NAMES[] = {
-  ITEM_LIST
+  PM_ITEM_LIST
 };
 
@@ -216,4 +220,5 @@
 char *get_input_filename(void);
 char *get_starfield_filename(void);
+void get_starfield_center(int *rh,int *rm,int *rs,int *dd,int *dm,int *ds);
 char *get_data_filename(void);
 char *get_root_filename(void);
@@ -250,4 +255,7 @@
 void get_threshold(float *t);
 int get_indi_thres_pixel(void);
+void get_teles_axis(float *th, float *p);
+void get_source_off(float *th, float *p);
+int get_corsika_ver(void);
 //!@}
 
@@ -265,4 +273,7 @@
 /*
  * $Log: not supported by cvs2svn $
+ * Revision 1.9  2001/07/19 09:29:02  blanch
+ * Header file for creadparam.cxx vrsion 1.10
+ *
  * Revision 1.8  2001/03/05 10:44:44  blanch
  * Header file of creadparam.cxx version 1.9
@@ -135,12 +135,13 @@
 //!@{
 
-// now we define the list ITEM_LIST of possible items in
+// now we define the list PM_ITEM_LIST of possible items in
 // the parameters file. note that they are functions of
 // T(x). we will change T(x) to be the real item or the
